<?php


/**
 * @file
 * Form builder. Configure Ogone payments module
 *
 * @ingroup forms
 * @see system_settings_form().
 *
 */
 
/**
 * Form builder for the basic settings of the Ogone module. These settings reflect your merchant account settings at www.ogone.com
 */
function ogone_basicformsettings() {
  global $base_url;
  
  $form['general'] = array(
    '#type' => 'fieldset',
    '#title' => t('General'),
  );
  $form['general']['ogone_request_method'] = array(
    '#type' => 'radios',
    '#title' => t('Request method'),
    '#description' => t("Choose your request method.<br/>Must be equal to your ogone's technical setting point 1.1"),
    '#options' => array(
      'POST' => 'POST',
      'GET' => 'GET',
    ),
    '#default_value' => variable_get('ogone_request_method', 'POST')
  );
  $form['general']['ogone_PSPID'] = array(
    '#type' => 'textfield',
    '#title' => t('PSPID'),
    '#description' => t('Enter your PSPID at ogone.'),
    '#default_value' => variable_get('ogone_PSPID', '')
  );
  $form['general']['ogone_merchant_email'] = array(
    '#type' => 'textfield',
    '#title' => t('Merchant e-mail address'),
    '#description' => t('Enter your merchant e-mail address for feedback during fraud detection.'),
  '#default_value' => variable_get('ogone_merchant_email', ''),
  );
  $form['general']['ogone_currency'] = array(
    '#type' => 'textfield',
    '#title' => t('Currency'),
    '#description' => t('Enter your currency.'),
    '#default_value' => variable_get('ogone_currency', 'EUR')
  );
  $form['general']['ogone_language'] = array(
    '#type' => 'textfield',
    '#title' => t('Language'),
    '#description' => t('Enter your language.'),
    '#default_value' => variable_get('ogone_language', 'nl_BE')
  );
  $form['general']['ogone_actionurl'] = array(
    '#type' => 'textfield',
    '#title' => t('Action URL for payments'),
    '#description' => t('Action URL for payments, change test to prod after tests.'),
    '#default_value' => variable_get('ogone_actionurl', 'https://secure.ogone.com/ncol/test/orderstandard.asp')
  );
    
  $form['static'] = array(
    '#type' => 'fieldset',
    '#title' => t('Static template'),
  );
  $form['static']['ogone_title'] = array(
    '#type' => 'textfield',
    '#title' => t('Title'),
    '#description' => t('Title for static template.'),
    '#default_value' => variable_get('ogone_title', '')
  );
  $form['static']['ogone_bgcolor'] = array(
    '#type' => 'textfield',
    '#title' => t('Bgcolor'),
    '#description' => t('Background color for static template.'),
    '#default_value' => variable_get('ogone_bgcolor', '#4e84c4')
  );
  $form['static']['ogone_txtcolor'] = array(
    '#type' => 'textfield',
    '#title' => t('Txtcolor'),
    '#description' => t('Text color for static template.'),
    '#default_value' => variable_get('ogone_txtcolor', '#ffffff')
  );
  $form['static']['ogone_tblbgcolor'] = array(
    '#type' => 'textfield',
    '#title' => t('Tblbgcolor'),
    '#description' => t('Table background color for static template.'),
    '#default_value' => variable_get('ogone_tblbgcolor', '#ffffff')
  );
  $form['static']['ogone_tbltxtcolor'] = array(
    '#type' => 'textfield',
    '#title' => t('Tbltxtcolor'),
    '#description' => t('Table text color for static template.'),
    '#default_value' => variable_get('ogone_tbltxtcolor', '#000000')
  );
  $form['static']['ogone_buttonbgcolor'] = array(
    '#type' => 'textfield',
    '#title' => t('Buttonbgcolor'),
    '#description' => t('Button background color for static template.'),
    '#default_value' => variable_get('ogone_buttonbgcolor', '#00467f')
  );
  $form['static']['ogone_buttontxtcolor'] = array(
    '#type' => 'textfield',
    '#title' => t('Buttontxtcolor'),
    '#description' => t('Button text color for static template.'),
    '#default_value' => variable_get('ogone_buttontxtcolor', '#ffffff')
  );
  $form['static']['ogone_fonttype'] = array(
    '#type' => 'textfield',
    '#title' => t('Fonttype'),
    '#description' => t('Font type for static template.'),
    '#default_value' => variable_get('ogone_fonttype', 'Verdana')
  );
  $form['static']['ogone_logo'] = array(
    '#type' => 'textfield',
    '#title' => t('Logo'),
    '#description' => t('Logo filename for static template: send logo to support with your PSPID in the subject.'),
    '#default_value' => variable_get('ogone_logo', '')
  );

  $form['dynamic'] = array(
    '#type' => 'fieldset',
    '#title' => t('Dynamic template'),
  );
  $form['dynamic']['ogone_TP'] = array(
    '#type' => 'textfield',
    '#title' => t('TP'),
    '#description' => t("The full URL of the template Page hosted on the merchant's site and containing the <em>payment string</em>."),
    '#default_value' => variable_get('ogone_TP', '')
  );

  $form['postpayment'] = array(
    '#type' => 'fieldset',
    '#title' => t('Post-payment redirection'),
  );
  $form['postpayment']['ogone_accepturl'] = array(
    '#type' => 'hidden',
    '#value' => variable_get('ogone_accepturl', $base_url .'/ogone/paymentresult')
  );
  $form['postpayment']['ogone_declineurl'] = array(
    '#type' => 'hidden',
    '#value' => variable_get('ogone_declineurl', $base_url .'/ogone/paymentresult')
  );
  $form['postpayment']['ogone_exceptionurl'] = array(
    '#type' => 'hidden',
    '#value' => variable_get('ogone_exceptionurl', $base_url .'/ogone/paymentresult')
  );
  $form['postpayment']['ogone_cancelurl'] = array(
    '#type' => 'hidden',
    '#value' => variable_get('ogone_cancelurl', $base_url .'/ogone/paymentresult')
  );
  $form['postpayment']['ogone_homeurl'] = array(
    '#type' => 'textfield',
    '#title' => t('Home URL'),
    '#description' => t('The URL to redirect to home page.'),
    '#default_value' => variable_get('ogone_homeurl', '')
  );
  $form['postpayment']['ogone_catalogurl'] = array(
    '#type' => 'textfield',
    '#title' => t('Catalog URL'),
    '#description' => t('The URL to redirect to catalogue page.'),
    '#default_value' => variable_get('ogone_catalogurl', '')
  );

  $form['secure'] = array(
    '#type' => 'fieldset',
    '#title' => t('Security settings'),
  );
  $form['secure']['ogone_SHA1_bp'] = array(
    '#type' => 'textfield',
    '#title' => t('SHA1 before payment'),
    '#description' => t('SHA1 signature before payment.<br/>Default works, but it is advised to create your own signature.<br/>Copy and paste this signature into the field 3.2 SHA1 signature on the technical settings of your Ogone account'),
    '#default_value' => variable_get('ogone_SHA1_bp', strtoupper(md5(rand(1, 10000) . md5(variable_get('site_name', "Default site name")) . variable_get('site_name', "Default site name") . rand(1, 10000))))
  );
  $form['secure']['ogone_SHA1_fb'] = array(
    '#type' => 'textfield',
    '#title' => t('SHA1 feedback data checking'),
    '#description' => t('SHA1 signature for feedback.<br/>Default works, but it is advised to create your own signature.<br/>Copy and paste this signature into the field 4.4 SHA1 signature on the technical settings of your Ogone account'),
    '#default_value' => variable_get('ogone_SHA1_fb', strtoupper(md5(rand(1, 10000) . variable_get('site_name', "Default site name") . md5(variable_get('site_name', "Default site name") . rand(1, 10000)))))
  );
  $form['secure']['ogone_SHA1_mn'] = array(
    '#type' => 'textfield',
    '#title' => t('SHA1 feedback module checking'),
    '#description' => t('Decisions are made based on the module name in the PARAMPLUS. To make sure nobody tampered with it we hash it with an extra signature.<br/>Default works, but it is advised to create your own signature.<br/>This signature is NOT for ogone\'s technical settings'),
    '#default_value' => variable_get('ogone_SHA1_mn', strtoupper(md5(rand(1, 10000) . rand(1, 10000) . variable_get('site_name', "Default site name") . md5(variable_get('site_name', "Default site name") . rand(1, 10000)))))
  );

  return system_settings_form($form);
}

/**
 * Form builder for the setting prefixes for each of the modules that implement the hooks provided by the Ogone module.
 */
function ogone_prefixform() {
  foreach (module_implements('ogone_data') as $module) {
    $form['ogone_'. $module .'_prefix'] = array(
      '#type' => 'textfield',
      '#title' => t('Prefix for !module orders', array('!module' => $module)),
      '#description' => t('Enter a unique prefix to add to your order id for orders from module !module', array('!module' => $module)),
      '#default_value' => variable_get('ogone_'. $module .'_prefix', '')
    );
  }
  return system_settings_form($form);
}

/**
 * Validation of the ogone_prefixform submision. It basically checks for duplicate values
 */
function ogone_prefixform_validate($form, &$form_state) {
  $unique = array();
  foreach (module_implements('ogone_data') as $module) {
    if (!in_array($form_state['values']['ogone_'. $module .'_prefix'], $unique)) {
      $unique[] = $form_state['values']['ogone_'. $module .'_prefix'];
    }
    else {
      form_set_error('ogone_'. $module .'_prefix', t('Prefix for !module is already in use.', array('!module' => $module)));
    }
  }
}